@@ -1,6 +1,7 @@
 # ClamTk, copyright (C) 2004-2019 Dave M
 #
-# This file is part of ClamTk (https://dave-theunsub.github.io/clamtk).
+# This file is part of ClamTk
+# (https://gitlab.com/dave_m/clamtk-gtk3/).
 #
 # ClamTk is free software; you can redistribute it and/or modify it
 # under the terms of either:
@@ -23,28 +24,26 @@ use POSIX 'locale_h';
 use Locale::gettext;
 
 sub show_window {
-    my $top_box = Gtk2::EventBox->new;
+    my $top_box = Gtk3::EventBox->new;
 
-    # my $white = Gtk2::Gdk::Color->new( 0xFFFF, 0xFFFF, 0xFFFF );
-    # $top_box->modify_bg( 'normal', $white );
-
-    my $box = Gtk2::VBox->new( FALSE, 0 );
+    my $box = Gtk3::Box->new( 'vertical', 0 );
+    # $box->set_homogeneous(TRUE);
     $top_box->add( $box );
 
     my %prefs = ClamTk::Prefs->get_all_prefs();
 
-    my $grid = Gtk2::Table->new( 6, 1, FALSE );
+    my $grid = Gtk3::Grid->new();
     $box->pack_start( $grid, FALSE, FALSE, 10 );
-    $grid->set_col_spacings( 5 );
-    $grid->set_row_spacings( 5 );
-    $grid->set_homogeneous( TRUE );
+    $grid->set_column_spacing( 10 );
+    $grid->set_column_homogeneous( TRUE );
+    $grid->set_row_spacing( 10 );
+    $grid->set_row_homogeneous( TRUE );
 
-    my $option = Gtk2::CheckButton->new_with_label( _( 'Scan for PUAs' ) );
-    $option->can_focus( FALSE );
+    my $option = Gtk3::CheckButton->new_with_label( _( 'Scan for PUAs' ) );
     $option->set_tooltip_text(
         _( 'Detect packed binaries, password recovery tools, and more' ) );
     $option->set_active( TRUE ) if ( $prefs{ Thorough } );
-    $grid->attach_defaults( $option, 0, 1, 0, 1 );
+    $grid->attach( $option, 0, 0, 1, 1 );
     $option->signal_connect(
         toggled => sub {
             my $btn = shift;
@@ -54,12 +53,11 @@ sub show_window {
         }
     );
 
-    $option = Gtk2::CheckButton->new_with_label(
+    $option = Gtk3::CheckButton->new_with_label(
         _( 'Scan files beginning with a dot (.*)' ) );
-    $option->can_focus( FALSE );
     $option->set_tooltip_text( _( 'Scan files typically hidden from view' ) );
     $option->set_active( TRUE ) if ( $prefs{ ScanHidden } );
-    $grid->attach_defaults( $option, 0, 1, 1, 2 );
+    $grid->attach( $option, 0, 1, 1, 1 );
     $option->signal_connect(
         toggled => sub {
             my $btn = shift;
@@ -69,13 +67,12 @@ sub show_window {
         }
     );
 
-    $option = Gtk2::CheckButton->new_with_label(
+    $option = Gtk3::CheckButton->new_with_label(
         _( 'Scan files larger than 20 MB' ) );
-    $option->can_focus( FALSE );
     $option->set_tooltip_text(
         _( 'Scan large files which are typically not examined' ) );
     $option->set_active( TRUE ) if ( $prefs{ SizeLimit } );
-    $grid->attach_defaults( $option, 0, 1, 2, 3 );
+    $grid->attach( $option, 0, 2, 1, 1 );
     $option->signal_connect(
         toggled => sub {
             my $btn = shift;
@@ -85,13 +82,12 @@ sub show_window {
         }
     );
 
-    $option = Gtk2::CheckButton->new_with_label(
+    $option = Gtk3::CheckButton->new_with_label(
         _( 'Scan directories recursively' ) );
-    $option->can_focus( FALSE );
     $option->set_tooltip_text(
         _( 'Scan all files and directories within a directory' ) );
     $option->set_active( TRUE ) if ( $prefs{ Recursive } );
-    $grid->attach_defaults( $option, 0, 1, 3, 4 );
+    $grid->attach( $option, 0, 3, 1, 1 );
     $option->signal_connect(
         toggled => sub {
             my $btn = shift;
@@ -101,13 +97,12 @@ sub show_window {
         }
     );
 
-    $option = Gtk2::CheckButton->new_with_label(
+    $option = Gtk3::CheckButton->new_with_label(
         _( 'Check for updates to this program' ) );
-    $option->can_focus( FALSE );
     $option->set_tooltip_text(
         _( 'Check online for application and signature updates' ) );
     $option->set_active( TRUE ) if ( $prefs{ GUICheck } );
-    $grid->attach_defaults( $option, 0, 1, 4, 5 );
+    $grid->attach( $option, 0, 4, 1, 1 );
     $option->signal_connect(
         toggled => sub {
             my $btn = shift;
@@ -117,10 +112,11 @@ sub show_window {
         }
     );
 
-    my $infobar = Gtk2::InfoBar->new;
+    my $infobar = Gtk3::InfoBar->new;
     #$box->pack_start( $infobar, FALSE, FALSE, 10 );
     $infobar->set_message_type( 'other' );
-    $infobar->add_button( 'gtk-go-back', -7 );
+    my $use_image = ClamTk::Icons->get_image( 'go-previous' );
+    $infobar->add_button( $use_image, -7 );
     $infobar->signal_connect(
         response => sub {
             ClamTk::GUI->swap_button;
